aboutsummaryrefslogtreecommitdiffstats
path: root/api/src/main
diff options
context:
space:
mode:
authorBogdan Drutu <bdrutu@google.com>2017-06-16 12:29:28 -0700
committerGitHub <noreply@github.com>2017-06-16 12:29:28 -0700
commita7e1b0cb733a5c6b7cbe5b90a2ab57507be0c5bd (patch)
treef5e85e1193b893dc7a83a6cdd1e782aae6854488 /api/src/main
parent42b6a876452906936741203cc93f34716a841ce4 (diff)
downloadplatform_external_opencensus-java-a7e1b0cb733a5c6b7cbe5b90a2ab57507be0c5bd.tar.gz
platform_external_opencensus-java-a7e1b0cb733a5c6b7cbe5b90a2ab57507be0c5bd.tar.bz2
platform_external_opencensus-java-a7e1b0cb733a5c6b7cbe5b90a2ab57507be0c5bd.zip
Rename ActiveSpansExporter to RunningSpanStore. (#362)
Diffstat (limited to 'api/src/main')
-rw-r--r--api/src/main/java/io/opencensus/trace/export/ExportComponent.java10
-rw-r--r--api/src/main/java/io/opencensus/trace/export/RunningSpanStore.java (renamed from api/src/main/java/io/opencensus/trace/export/ActiveSpansExporter.java)40
2 files changed, 25 insertions, 25 deletions
diff --git a/api/src/main/java/io/opencensus/trace/export/ExportComponent.java b/api/src/main/java/io/opencensus/trace/export/ExportComponent.java
index 99e73a6c..f1199e39 100644
--- a/api/src/main/java/io/opencensus/trace/export/ExportComponent.java
+++ b/api/src/main/java/io/opencensus/trace/export/ExportComponent.java
@@ -18,7 +18,7 @@ import javax.annotation.Nullable;
/**
* Class that holds the implementation instances for {@link SpanExporter}, {@link
- * ActiveSpansExporter} and {@link SampledSpanStore}.
+ * RunningSpanStore} and {@link SampledSpanStore}.
*
* <p>Unless otherwise noted all methods (on component) results are cacheable.
*/
@@ -45,13 +45,13 @@ public abstract class ExportComponent {
public abstract SpanExporter getSpanExporter();
/**
* Returns the {@link ActiveSpansExporter} that can be used to get useful debugging information
* about all the current active spans.
*
- * @return the {@code ActiveSpansExporter} or {@code null} if not supported.
+ * @return the {@code RunningSpanStore} or {@code null} if not supported.
*/
@Nullable
- public abstract ActiveSpansExporter getActiveSpansExporter();
+ public abstract RunningSpanStore getRunningSpanStore();
/**
* Returns the {@link SampledSpanStore} that can be used to get useful debugging information, such
@@ -70,7 +70,7 @@ public abstract class ExportComponent {
@Nullable
@Override
- public ActiveSpansExporter getActiveSpansExporter() {
+ public RunningSpanStore getRunningSpanStore() {
return null;
}
@@ -45,13 +45,13 @@ public abstract class ExportComponent {
public abstract SpanExporter getSpanExporter();
/**
- * Returns the {@link ActiveSpansExporter} that can be used to get useful debugging information
+ * Returns the {@link RunningSpanStore} that can be used to get useful debugging information
* about all the current active spans.
*
diff --git a/api/src/main/java/io/opencensus/trace/export/ActiveSpansExporter.java b/api/src/main/java/io/opencensus/trace/export/RunningSpanStore.java
index c6c5b8da..19facc8a 100644
--- a/api/src/main/java/io/opencensus/trace/export/ActiveSpansExporter.java
+++ b/api/src/main/java/io/opencensus/trace/export/RunningSpanStore.java
@@ -26,31 +26,31 @@ import javax.annotation.concurrent.Immutable;
import javax.annotation.concurrent.ThreadSafe;
/**
* This class allows users to access in-process information about all active spans.
*
* <p>The active spans tracking is available for all the spans with the option {@link
* Span.Options#RECORD_EVENTS}. This functionality allows users to debug stuck operations or long
* living operations.
*/
@ThreadSafe
-public abstract class ActiveSpansExporter {
+public abstract class RunningSpanStore {
- protected ActiveSpansExporter() {}
+ protected RunningSpanStore() {}
/**
* Returns the summary of all available data such, as number of active spans.
*
* @return the summary of all available data.
*/
public abstract Summary getSummary();
/**
* Returns a list of active spans that match the {@code Filter}.
*
* @param filter used to filter the returned spans.
* @return a list of active spans that match the {@code Filter}.
*/
- public abstract Collection<SpanData> getActiveSpans(Filter filter);
+ public abstract Collection<SpanData> getRunningSpans(Filter filter);
/** The summary of all available data. */
@AutoValue
@@ -67,7 +67,7 @@ public abstract class ActiveSpansExporter {
* @throws NullPointerException if {@code perSpanNameSummary} is {@code null}.
*/
public static Summary create(Map<String, PerSpanNameSummary> perSpanNameSummary) {
- return new AutoValue_ActiveSpansExporter_Summary(
+ return new AutoValue_RunningSpanStore_Summary(
Collections.unmodifiableMap(
new HashMap<String, PerSpanNameSummary>(
checkNotNull(perSpanNameSummary, "perSpanNameSummary"))));
@@ -91,26 +91,26 @@ public abstract class ActiveSpansExporter {
/**
* Returns a new instance of {@code PerSpanNameSummary}.
*
* @param numActiveSpans the number of sampled spans.
* @return a new instance of {@code PerSpanNameSummary}.
* @throws IllegalArgumentException if {@code numActiveSpans} is negative.
*/
- public static PerSpanNameSummary create(int numActiveSpans) {
- checkArgument(numActiveSpans >= 0, "Negative numActiveSpans.");
- return new AutoValue_ActiveSpansExporter_PerSpanNameSummary(numActiveSpans);
+ public static PerSpanNameSummary create(int numRunningSpans) {
+ checkArgument(numRunningSpans >= 0, "Negative numRunningSpans.");
+ return new AutoValue_RunningSpanStore_PerSpanNameSummary(numRunningSpans);
}
/**
* Returns the number of active spans.
*
* @return the number of active spans.
*/
- public abstract int getNumActiveSpans();
+ public abstract int getNumRunningSpans();
}
/**
- * Filter for active spans. Used to filter results returned by the {@link #getActiveSpans(Filter)}
- * request.
+ * Filter for running spans. Used to filter results returned by the
+ * {@link #getRunningSpans(Filter)} request.
*/
@AutoValue
@Immutable
@@ -132,7 +132,7 @@ public abstract class ActiveSpansExporter {
*/
public static Filter create(String spanName, int maxSpansToReturn) {
checkArgument(maxSpansToReturn >= 0, "Negative maxSpansToReturn.");
- return new AutoValue_ActiveSpansExporter_Filter(spanName, maxSpansToReturn);
+ return new AutoValue_RunningSpanStore_Filter(spanName, maxSpansToReturn);
}
/**
@@ -26,31 +26,31 @@ import javax.annotation.concurrent.Immutable;
import javax.annotation.concurrent.ThreadSafe;
/**
- * This class allows users to access in-process information about all active spans.
+ * This class allows users to access in-process information about all running spans.
*
@@ -26,31 +26,31 @@ import javax.annotation.concurrent.Immutable;
*
- * <p>The active spans tracking is available for all the spans with the option {@link
+ * <p>The running spans tracking is available for all the spans with the option {@link
* Span.Options#RECORD_EVENTS}. This functionality allows users to debug stuck operations or long
* living operations.
@@ -26,31 +26,31 @@ import javax.annotation.concurrent.Immutable;
/**
- * Returns the summary of all available data such, as number of active spans.
+ * Returns the summary of all available data such, as number of running spans.
*
* @return the summary of all available data.
@@ -26,31 +26,31 @@ import javax.annotation.concurrent.Immutable;
public abstract Summary getSummary();
/**
- * Returns a list of active spans that match the {@code Filter}.
+ * Returns a list of running spans that match the {@code Filter}.
*
* @param filter used to filter the returned spans.
@@ -26,31 +26,31 @@ import javax.annotation.concurrent.Immutable;
*
* @param filter used to filter the returned spans.
- * @return a list of active spans that match the {@code Filter}.
+ * @return a list of running spans that match the {@code Filter}.
*/
@@ -91,26 +91,26 @@ public abstract class ActiveSpansExporter {
* Returns a new instance of {@code PerSpanNameSummary}.
*
- * @param numActiveSpans the number of sampled spans.
+ * @param numRunningSpans the number of running spans.
* @return a new instance of {@code PerSpanNameSummary}.
@@ -91,26 +91,26 @@ public abstract class ActiveSpansExporter {
* @return a new instance of {@code PerSpanNameSummary}.
- * @throws IllegalArgumentException if {@code numActiveSpans} is negative.
+ * @throws IllegalArgumentException if {@code numRunningSpans} is negative.
*/
@@ -91,26 +91,26 @@ public abstract class ActiveSpansExporter {
}
/**
- * Returns the number of active spans.
+ * Returns the number of running spans.
*
@@ -91,26 +91,26 @@ public abstract class ActiveSpansExporter {
*
- * @return the number of active spans.
+ * @return the number of running spans.
*/